package com.jjt.wkEmp.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.wkEmp.domain.TwinWkEmpRota;

/**
 * 经编车间员工排班Mapper接口
 * 
 * @author wukai
 * @date 2025-04-28
 */
public interface TwinWkEmpRotaMapper extends BaseMapper<TwinWkEmpRota>
{
    /**
     * 查询经编车间员工排班
     * 
     * @param shiftId 经编车间员工排班主键
     * @return 经编车间员工排班
     */
    public TwinWkEmpRota selectTwinWkEmpRotaByShiftId(Long shiftId);

    /**
     * 查询经编车间员工排班列表
     * 
     * @param twinWkEmpRota 经编车间员工排班
     * @return 经编车间员工排班集合
     */
    public List<TwinWkEmpRota> selectTwinWkEmpRotaList(TwinWkEmpRota twinWkEmpRota);

    /**
     * 新增经编车间员工排班
     * 
     * @param twinWkEmpRota 经编车间员工排班
     * @return 结果
     */
    public int insertTwinWkEmpRota(TwinWkEmpRota twinWkEmpRota);

    /**
     * 修改经编车间员工排班
     * 
     * @param twinWkEmpRota 经编车间员工排班
     * @return 结果
     */
    public int updateTwinWkEmpRota(TwinWkEmpRota twinWkEmpRota);

    /**
     * 删除经编车间员工排班
     * 
     * @param shiftId 经编车间员工排班主键
     * @return 结果
     */
    public int deleteTwinWkEmpRotaByShiftId(Long shiftId);

    /**
     * 批量删除经编车间员工排班
     * 
     * @param shiftIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinWkEmpRotaByShiftIds(Long[] shiftIds);
}
